==> FHLBBS-5.3.tgz: php/ann.php <==
<?php
/***** ΨӳBzذϪ { ***************************/
 require("config.php");
 require("wbbs.php");
 require("auth.php");
 session_register("userid","cuser","currboard","cbrd");
 define("MAXITEMS",    1024);       /* @hؿ̦hXH */
 define("PATHLEN",      128);      
 define("ADDITEM",      0);       
 define("ADDGROUP",1);
 /****wq@ǤΪܼ *****/
 $fn_mandex  = ".Names";
 class ITEM
 {
        var     $title;        /* D */
        var     $fdate;      /*  [mm/dd/yyyy] */
        var     $fname;        /* ɦW */
        var     $access;         /* v */
  }
  $ITEMA=array();	/*****Vت}C*****/
  $mtitle="ذ"; /* D */
  $path="";	/*ؿ*/
  $num=0;
  $level=0;
  $MANDIR="/home/bbs/man/";
  $fun=(int) $_REQUEST["fun"]; // get function fun=0 read
  $pathin=$_REQUEST["path"];   //get path
  if (strlen($pathin)==0) //SJpath
     $NOWDIR="";
  else
     $NOWDIR=$pathin."/"; //ثeذϬ۹ؿ
  if (strpos($pathin, "..")!==false)
	die ("AObȶܡH");	
  if (strpos($pathin, "|")!==false)
	die ("AObȶܡH");	
  if (strpos($pathin, "&")!==false)
	die ("AObȶܡH");	
  if (strpos($pathin, ">")!==false)
	die ("AObȶܡH");	
  if (strpos($pathin, "<")!==false)
	die ("AObȶܡH");	
  if (strpos($pathin, ";")!==false)
	die ("AObȶܡH");	
  // for FHL BBS
  if (strpos($pathin, "IDIntroduce")!==false)
	die ("S");	

  $board=strtok($pathin," /\n"); //XQװ
  /*** ˬdQװv  **/
  if (strlen($board)>0)
  {
     $cbrd=searchbrd($board);
     if ($cbrd && (!Ben_Perm($cbrd))) //QװϨSvp
        die("$pathin ɮŪ~!<p>\n");
  }
  if ($fun==0) // READ
  {
        $access=0;
	$item= new ITEM;
	$buf=$MANDIR.$NOWDIR.$fn_mandex ;
         if(($fd = fopen($buf, "r"))===false)
                die ("{$buf}Lk}ҡI<br>\n");
	 /******* Bzɮ **********/
	$this->num=0;
  	while ($buf=fgets($fd, 255))
    	{
      	   $buf=trim($buf);
           if (!strncmp($buf, "Name=", 5))
           {
               $item->title=substr($buf,5);
           }
           elseif (!strncmp($buf, "Date=", 5))
           {
	      $item->fdate=substr($buf,5);
           }
           elseif (!strncmp($buf, "Path=", 5))
           {
              $item->fname=$NOWDIR.substr($buf,5);
              if (strlen($item->fdate)== 0)
		     $item->fdate=date("[m/d/Y]");
	      if (HAS_PERM(PERM_LEVEL3)) $a_user_access_level = 3;           /* ĤT */
              elseif (HAS_PERM(PERM_LEVEL2)) $a_user_access_level = 2;      /* ĤG */
              else $a_user_access_level = 1;                                 /* Ĥ@ */
              /*  user ϥεŵP\Ūv */
              if ($a_user_access_level >= $access) {
	         $ITEMA[$num]=$item;
	         $num=$num+1;
                 $access = 1;
              }
              $item->fdate[0] = "";
           }
           elseif (!strncmp($buf, "Access=", 7))
           {
              $item->access=substr($buf,7,1);
              $access = (int) $item->access;
	      if ($access<=0) 
	      {
		$access=1;
		$item->access="1";
	      }
           }
           elseif (!strncmp($buf, "# Title=", 8))
           {
             $mtitle=substr($buf,8);
      	   }
        } //while
         fclose($fd);
         /*****}l show X ********/
	echo "<h2>$mtitle</h2>\n";
	echo "<table border=\"1\">\n";
	echo "<tr align=\"center\"><td>s</td><td>ݩ<td>W</td><td></td></tr>\n";
        for ($i=0;$i<$num;$i=$i+1)
	{
	    $ii=$i+1;
	    echo "<tr><td>{$ii}</td>";
	    $fn=$MANDIR.$ITEMA[$i]->fname;
            if (is_dir($fn)) //pGOؿ
           	{
		   echo "<td>ؿ</td>";
		   echo "<td><a href=\"$PHP_SELF?fun=0&path={$ITEMA[$i]->fname}\">{$ITEMA[$i]->title}</a></td>";
		   echo "<td>[{$ITEMA[$i]->fdate}]</td></tr>\n";
		}
            else //pGOؿ
           	{
		   echo "<td>ɮ</td>";
		   echo "<td><a href=\"$PHP_SELF?fun=1&path={$ITEMA[$i]->fname}\">{$ITEMA[$i]->title}</a></td>";
		   echo "<td>[{$ITEMA[$i]->fdate}]</td></tr>\n";
		}
	}//for
	echo "</table>";
	$prev=dirname($pathin);
        echo "<p><a href=\"$PHP_SELF?fun=0&path={$prev}\">^W@h</a>\n";
        echo "@@<a href=\"$PHP_SELF?fun=0\">^̤Wh</a><p>\n";
     }//READ fun
     if ($fun==1) // READ Article
     {
	$fn=$MANDIR.$pathin;
	$prev=dirname($pathin);
	if (is_dir($fn)) //pGOؿ
	{
		die("oӤO@ɮ");
	}
        echo "<a href=\"$PHP_SELF?fun=0&path={$prev}\">^W@h</a><p>\n";
	echo " <pre>\n";
	readfile($fn);
	echo "</pre>\n";
        echo "<a href=\"$PHP_SELF?fun=0&path={$prev}\">^W@h</a><p>\n";
     }
?>

==> FHLBBS-5.4.tgz: php/ann.php <==
<?php
/***** ΨӳBzذϪ { ***************************/
 require("config.php");
 require("wbbs.php");
 require("auth.php");
 session_register("userid","cuser","currboard","cbrd");
 define("MAXITEMS",    1024);       /* @hؿ̦hXH */
 define("PATHLEN",      128);      
 define("ADDITEM",      0);       
 define("ADDGROUP",1);
 /****wq@ǤΪܼ *****/
 $fn_mandex  = ".Names";
 class ITEM
 {
        var     $title;        /* D */
        var     $fdate;      /*  [mm/dd/yyyy] */
        var     $fname;        /* ɦW */
        var     $access;         /* v */
  }
  $ITEMA=array();	/*****Vت}C*****/
  $mtitle="ذ"; /* D */
  $path="";	/*ؿ*/
  $num=0;
  $level=0;
  $MANDIR="/home/bbs/man/";
  $fun=(int) $_REQUEST["fun"]; // get function fun=0 read
  $pathin=$_REQUEST["path"];   //get path
  if (strlen($pathin)==0) //SJpath
     $NOWDIR="";
  else
     $NOWDIR=$pathin."/"; //ثeذϬ۹ؿ
  if (strpos($pathin, "..")!==false)
	die ("AObȶܡH");	
  if (strpos($pathin, "|")!==false)
	die ("AObȶܡH");	
  if (strpos($pathin, "&")!==false)
	die ("AObȶܡH");	
  if (strpos($pathin, ">")!==false)
	die ("AObȶܡH");	
  if (strpos($pathin, "<")!==false)
	die ("AObȶܡH");	
  if (strpos($pathin, ";")!==false)
	die ("AObȶܡH");	
  // for FHL BBS
  if (strpos($pathin, "IDIntroduce")!==false)
	die ("S");	

  $board=strtok($pathin," /\n"); //XQװ
  /*** ˬdQװv  **/
  if (strlen($board)>0)
  {
     $cbrd=searchbrd($board);
     if ($cbrd && (!Ben_Perm($cbrd))) //QװϨSvp
        die("$pathin ɮŪ~!<p>\n");
  }
  if ($fun==0) // READ
  {
        $access=0;
	$item= new ITEM;
	$buf=$MANDIR.$NOWDIR.$fn_mandex ;
         if(($fd = fopen($buf, "r"))===false)
                die ("{$buf}Lk}ҡI<br>\n");
	 /******* Bzɮ **********/
	$this->num=0;
  	while ($buf=fgets($fd, 255))
    	{
      	   $buf=trim($buf);
           if (!strncmp($buf, "Name=", 5))
           {
               $item->title=substr($buf,5);
           }
           elseif (!strncmp($buf, "Date=", 5))
           {
	      $item->fdate=substr($buf,5);
           }
           elseif (!strncmp($buf, "Path=", 5))
           {
              $item->fname=$NOWDIR.substr($buf,5);
              if (strlen($item->fdate)== 0)
		     $item->fdate=date("[m/d/Y]");
	      if (HAS_PERM(PERM_LEVEL3)) $a_user_access_level = 3;           /* ĤT */
              elseif (HAS_PERM(PERM_LEVEL2)) $a_user_access_level = 2;      /* ĤG */
              else $a_user_access_level = 1;                                 /* Ĥ@ */
              /*  user ϥεŵP\Ūv */
              if ($a_user_access_level >= $access) {
	         $ITEMA[$num]=$item;
	         $num=$num+1;
                 $access = 1;
              }
              $item->fdate[0] = "";
           }
           elseif (!strncmp($buf, "Access=", 7))
           {
              $item->access=substr($buf,7,1);
              $access = (int) $item->access;
	      if ($access<=0) 
	      {
		$access=1;
		$item->access="1";
	      }
           }
           elseif (!strncmp($buf, "# Title=", 8))
           {
             $mtitle=substr($buf,8);
      	   }
        } //while
         fclose($fd);
         /*****}l show X ********/
	echo "<h2>$mtitle   <a href=\"/\">^BBS</a></h2>\n";
	echo "<table border=\"1\">\n";
	echo "<tr align=\"center\"><td>s</td><td>ݩ<td>W</td><td></td></tr>\n";
        for ($i=0;$i<$num;$i=$i+1)
	{
	    $ii=$i+1;
	    echo "<tr><td>{$ii}</td>";
	    $fn=$MANDIR.$ITEMA[$i]->fname;
            if (is_dir($fn)) //pGOؿ
           	{
		   echo "<td>ؿ</td>";
		   echo "<td><a href=\"$PHP_SELF?fun=0&path={$ITEMA[$i]->fname}\">{$ITEMA[$i]->title}</a></td>";
		   echo "<td>[{$ITEMA[$i]->fdate}]</td></tr>\n";
		}
            else //pGOؿ
           	{
		   echo "<td>ɮ</td>";
		   echo "<td><a href=\"$PHP_SELF?fun=1&path={$ITEMA[$i]->fname}\">{$ITEMA[$i]->title}</a></td>";
		   echo "<td>[{$ITEMA[$i]->fdate}]</td></tr>\n";
		}
	}//for
	echo "</table>";
	$prev=dirname($pathin);
        echo "<p><a href=\"$PHP_SELF?fun=0&path={$prev}\">^W@h</a>\n";
        echo "@@<a href=\"$PHP_SELF?fun=0\">^̤Wh</a><p>\n";
     }//READ fun
     if ($fun==1) // READ Article
     {
	$fn=$MANDIR.$pathin;
	$prev=dirname($pathin);
	if (is_dir($fn)) //pGOؿ
	{
		die("oӤO@ɮ");
	}
        echo "<a href=\"$PHP_SELF?fun=0&path={$prev}\">^W@h</a><p>\n";
	$fptr1 = fopen($fn, "r");
	pfile($fptr1);
        echo "<a href=\"$PHP_SELF?fun=0&path={$prev}\">^W@h</a><p>\n";
     }
?>
